@@ -22,7 +22,7 @@ Integer constraint.
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint::Regex>,
 L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
