@@ -319,7 +319,7 @@ sub process {
         my $parent = $self;
 
         while ( defined( $parent = $parent->parent ) ) {
-            my $field = $parent->get_field( $counter_name );
+            my $field = $parent->get_field({ original_name => $counter_name });
 
             if ( defined $field ) {
                 $counter_name = $field->nested_name;
@@ -499,6 +499,8 @@ returned by L</repeat>, starting at number C<1>.
 Because this is an 'inherited accessor' available on all elements, it can be
 used to determine whether any element is a child of a Repeatable element.
 
+Only available after L<repeat> has been called.
+
 =head2 nested_name
 
 If the L</nested_name> attribute is set, the naming scheme of the Repeatable
@@ -606,6 +608,20 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
 Not supported for Repeatable elements - will throw a fatal error if called as
 a setter.
 
+=head1 CAVEATS
+
+=head2 Unsupported Constraints
+
+Note that constraints with an L<others|HTML::FormFu::Constraint::_others> 
+method do not work correctly within a Repeatable block. Currently, these are:
+L<AllOrNone|HTML::FormFu::Constraint::AllOrNone>, 
+L<DependOn|HTML::FormFu::Constraint::DependOn>, 
+L<Equal|HTML::FormFu::Constraint::Equal>, 
+L<MinMaxFields|HTML::FormFu::Constraint::MinMaxFields>, 
+L<reCAPTCHA|HTML::FormFu::Constraint::reCAPTCHA>.
+Also, the L<CallbackOnce|HTML::FormFu::Constraint::CallbackOnce> constraint
+won't work within a Repeatable block, as it wouldn't make much sense.
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from
